==> fHMM_1.1.1.tar.gz: fHMM/tests/testthat/_snaps/fHMM_controls.md <==
# checks of controls for simulated HMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: FALSE 
      * data type: simulated 
      * number of states: 2 
      * sdds: t() 
      * number of runs: 50  

# checks of controls for empirical HMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: FALSE 
      * data type: empirical 
      * number of states: 2 
      * sdds: t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: FALSE 
      * data type: empirical 
      * number of states: 2 
      * sdds: t() 
      * number of runs: 100  

# checks of controls for simulated HHMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

# checks of controls for empirical HHMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: t() t() 
      * number of runs: 100

==> fHMM_1.2.1.tar.gz: fHMM/tests/testthat/_snaps/fHMM_controls.md <==
# checks of controls for simulated HMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: FALSE 
      * data type: simulated 
      * number of states: 2 
      * sdds: t() 
      * number of runs: 50  

# checks of controls for empirical HMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: FALSE 
      * data type: empirical 
      * number of states: 2 
      * sdds: t() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: FALSE 
      * data type: empirical 
      * number of states: 2 
      * sdds: t() 
      * number of runs: 100  

# checks of controls for simulated HHMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: simulated 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

# checks of controls for empirical HHMM work

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100  

---

    Code
      controls
    Output
      fHMM controls:
      * hierarchy: TRUE 
      * data type: empirical 
      * number of states: 2 2 
      * sdds: normal() normal() 
      * number of runs: 100
